# Advanced Examples

Simple examples are good to get you started, but they don't show the full power
of `fasthep-flow`. In this section, we will go through some more advanced
examples, and show how to use `fasthep-flow` to perform a full HEP analysis with
paper-ready plots and tables.

Here is a list:

```{toctree}
cms_full_analysis_example.md
```
